@@ -3,7 +3,7 @@
 from decimal import Decimal
 import copy
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.wizard import Wizard
+from trytond.wizard import Wizard, StateView, StateAction, Button
 from trytond.pyson import Eval, PYSONEncoder
 from trytond.transaction import Transaction
 from trytond.pool import Pool
@@ -14,9 +14,9 @@ class Account(ModelSQL, ModelView):
     _name = 'analytic_account.account'
     _description = __doc__
 
-    name = fields.Char('Name', required=True, translate=True, select=1)
-    code = fields.Char('Code', select=1)
-    active = fields.Boolean('Active', select=2)
+    name = fields.Char('Name', required=True, translate=True, select=True)
+    code = fields.Char('Code', select=True)
+    active = fields.Boolean('Active', select=True)
     company = fields.Many2One('company.company', 'Company')
     currency = fields.Many2One('currency.currency', 'Currency', required=True)
     currency_digits = fields.Function(fields.Integer('Currency Digits',
@@ -26,14 +26,14 @@ class Account(ModelSQL, ModelView):
         ('view', 'View'),
         ('normal', 'Normal'),
         ], 'Type', required=True)
-    root = fields.Many2One('analytic_account.account', 'Root', select=2,
-        domain=[('parent', '=', False)],
+    root = fields.Many2One('analytic_account.account', 'Root', select=True,
+        domain=[('parent', '=', None)],
         states={
             'invisible': Eval('type') == 'root',
             'required': Eval('type') != 'root',
             },
         depends=['type'])
-    parent = fields.Many2One('analytic_account.account', 'Parent', select=2,
+    parent = fields.Many2One('analytic_account.account', 'Parent', select=True,
         domain=[('parent', 'child_of', Eval('root'))],
         states={
             'invisible': Eval('type') == 'root',
@@ -79,15 +79,13 @@ class Account(ModelSQL, ModelView):
         return True
 
     def default_company(self):
-        return Transaction().context.get('company') or False
+        return Transaction().context.get('company')
 
     def default_currency(self):
         company_obj = Pool().get('company.company')
-        currency_obj = Pool().get('currency.currency')
         if Transaction().context.get('company'):
             company = company_obj.browse(Transaction().context['company'])
             return company.currency.id
-        return False
 
     def default_type(self):
         return 'normal'
@@ -256,7 +254,7 @@ class Account(ModelSQL, ModelView):
         element_accounts = res[0]
 
         root_account_ids = self.search([
-            ('parent', '=', False),
+            ('parent', '=', None),
             ])
         if not root_account_ids:
             element_accounts.getparent().getparent().remove(
@@ -279,7 +277,7 @@ class Account(ModelSQL, ModelView):
             fields_names = []
 
         root_account_ids = self.search([
-            ('parent', '=', False),
+            ('parent', '=', None),
             ])
         for account in self.browse(root_account_ids):
             name = 'analytic_account_' + str(account.id)
@@ -296,50 +294,36 @@ class Account(ModelSQL, ModelView):
 Account()
 
 
-class OpenChartAccountInit(ModelView):
-    'Open Chart Account Init'
-    _name = 'analytic_account.account.open_chart_account.init'
+class OpenChartAccountStart(ModelView):
+    'Open Chart of Accounts'
+    _name = 'analytic_account.open_chart.start'
     _description = __doc__
     start_date = fields.Date('Start Date')
     end_date = fields.Date('End Date')
 
-OpenChartAccountInit()
+OpenChartAccountStart()
 
 
 class OpenChartAccount(Wizard):
-    'Open Chart Of Account'
-    _name = 'analytic_account.account.open_chart_account'
-    states = {
-        'init': {
-            'result': {
-                'type': 'form',
-                'object': 'analytic_account.account.open_chart_account.init',
-                'state': [
-                    ('end', 'Cancel', 'tryton-cancel'),
-                    ('open', 'Open', 'tryton-ok', True),
-                ],
-            },
-        },
-        'open': {
-            'result': {
-                'type': 'action',
-                'action': '_action_open_chart',
-                'state': 'end',
-            },
-        },
-    }
+    'Open Chart of Accounts'
+    _name = 'analytic_account.open_chart'
 
-    def _action_open_chart(self, data):
-        model_data_obj = Pool().get('ir.model.data')
-        act_window_obj = Pool().get('ir.action.act_window')
-        act_window_id = model_data_obj.get_id('analytic_account',
-                'act_account_tree2')
-        res = act_window_obj.read(act_window_id)
-        res['pyson_context'] = PYSONEncoder().encode({
-            'start_date': data['form']['start_date'],
-            'end_date': data['form']['end_date'],
-            })
-        return res
+    start = StateView('analytic_account.open_chart.start',
+        'analytic_account.open_chart_start_view_form', [
+            Button('Cancel', 'end', 'tryton-cancel'),
+            Button('Open', 'open_', 'tryton-ok', default=True),
+            ])
+    open_ = StateAction('analytic_account.act_account_tree2')
+
+    def do_open_(self, session, action):
+        action['pyson_context'] = PYSONEncoder().encode({
+                'start_date': session.start.start_date,
+                'end_date': session.start.end_date,
+                })
+        return action, {}
+
+    def transition_open_(self, session):
+        return 'end'
 
 OpenChartAccount()
 
@@ -369,7 +353,7 @@ class AccountSelection(ModelSQL, ModelView):
         account_obj = Pool().get('analytic_account.account')
 
         root_account_ids = account_obj.search([
-            ('parent', '=', False),
+            ('parent', '=', None),
             ])
         root_accounts = account_obj.browse(root_account_ids)
 
@@ -380,7 +364,7 @@ class AccountSelection(ModelSQL, ModelView):
                 if account.root.id in roots:
                     return False
                 roots.append(account.root.id)
-            if Transaction().user: #Root can by pass
+            if Transaction().user:  # Root can by pass
                 for account in root_accounts:
                     if account.mandatory:
                         if not account.id in roots:
@@ -396,8 +380,8 @@ class AccountAccountSelection(ModelSQL):
     _description = __doc__
     _table = 'analytic_account_account_selection_rel'
     selection = fields.Many2One('analytic_account.account.selection',
-            'Selection', ondelete='CASCADE', required=True, select=1)
+            'Selection', ondelete='CASCADE', required=True, select=True)
     account = fields.Many2One('analytic_account.account', 'Account',
-            ondelete='RESTRICT', required=True, select=1)
+            ondelete='RESTRICT', required=True, select=True)
 
 AccountAccountSelection()
