@@ -1,8 +1,9 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 import time
+from decimal import Decimal
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.wizard import Wizard
+from trytond.wizard import Wizard, StateAction
 from trytond.backend import TableHandler
 from trytond.pyson import Eval, PYSONEncoder
 from trytond.transaction import Transaction
@@ -16,23 +17,23 @@ class Line(ModelSQL, ModelView):
 
     name = fields.Char('Name', required=True)
     debit = fields.Numeric('Debit', digits=(16, Eval('currency_digits', 2)),
-            depends=['currency_digits'])
+        required=True, depends=['currency_digits'])
     credit = fields.Numeric('Credit', digits=(16, Eval('currency_digits', 2)),
-            depends=['currency_digits'])
+        required=True, depends=['currency_digits'])
     currency = fields.Function(fields.Many2One('currency.currency', 'Currency',
         on_change_with=['move_line']), 'get_currency')
     currency_digits = fields.Function(fields.Integer('Currency Digits',
         on_change_with=['move_line']), 'get_currency_digits')
     account = fields.Many2One('analytic_account.account', 'Account',
-            required=True, select=1, domain=[('type', '!=', 'view')])
+            required=True, select=True, domain=[('type', '!=', 'view')])
     move_line = fields.Many2One('account.move.line', 'Account Move Line',
             ondelete='CASCADE', required=True)
     journal = fields.Many2One('account.journal', 'Journal', required=True,
-            select=1)
+            select=True)
     date = fields.Date('Date', required=True)
     reference = fields.Char('Reference')
     party = fields.Many2One('party.party', 'Party')
-    active = fields.Boolean('Active', select=2)
+    active = fields.Boolean('Active', select=True)
 
     def __init__(self):
         super(Line, self).__init__()
@@ -65,12 +66,17 @@ class Line(ModelSQL, ModelView):
     def default_active(self):
         return True
 
+    def default_debit(self):
+        return Decimal(0)
+
+    def default_credit(self):
+        return Decimal(0)
+
     def on_change_with_currency(self, vals):
         move_line_obj = Pool().get('account.move.line')
         if vals.get('move_line'):
             move_line = move_line_obj.browse(vals['move_line'])
             return move_line.account.company.currency.id
-        return False
 
     def get_currency(self, ids, name):
         res = {}
@@ -131,36 +137,25 @@ MoveLine()
 class OpenAccount(Wizard):
     'Open Account'
     _name = 'analytic_account.line.open_account'
-    states = {
-        'init': {
-            'result': {
-                'type': 'action',
-                'action': '_action_open_account',
-                'state': 'end',
-            },
-        },
-    }
-
-    def _action_open_account(self, data):
-        model_data_obj = Pool().get('ir.model.data')
-        act_window_obj = Pool().get('ir.action.act_window')
-
-        act_window_id = model_data_obj.get_id('analytic_account',
-                'act_line_form')
-        res = act_window_obj.read(act_window_id)
-        res['pyson_domain'] = [
-            ('account', '=', data['id']),
-        ]
+    start_state = 'open_'
+    open_ = StateAction('analytic_account.act_line_form')
 
+    def do_open_(self, session, action):
+        action['pyson_domain'] = [
+            ('account', '=', Transaction().context['active_id']),
+            ]
         if Transaction().context.get('start_date'):
-            res['pyson_domain'].append(
-                    ('date', '>=', Transaction().context['start_date'])
-                    )
+            action['pyson_domain'].append(
+                ('date', '>=', Transaction().context['start_date'])
+                )
         if Transaction().context.get('end_date'):
-            res['pyson_domain'].append(
-                    ('date', '<=', Transaction().context['end_date'])
-                    )
-        res['pyson_domain'] = PYSONEncoder().encode(res['pyson_domain'])
-        return res
+            action['pyson_domain'].append(
+                ('date', '<=', Transaction().context['end_date'])
+                )
+        action['pyson_domain'] = PYSONEncoder().encode(action['pyson_domain'])
+        return action, {}
+
+    def transition_open_(self, session):
+        return 'end'
 
 OpenAccount()
